pub enum DropResource {
Fun(Option<Box<dyn FnOnce()>>),
Struct(Box<dyn Any>),
}Expand description
A struct used by driver to tidy things up on javascript side after a rust object goes out of scope.
Variants
Implementations
Sourceimpl DropResource
impl DropResource
pub fn new<F: FnOnce() + 'static>(drop_fun: F) -> DropResource
pub fn from_struct(inst: impl Any) -> DropResource
pub fn off(self)